@@ -1,7 +1,7 @@
 package PlugAuth;
 
 # ABSTRACT: Pluggable authentication and authorization server.
-our $VERSION = '0.33'; # VERSION
+our $VERSION = '0.34'; # VERSION
 
 
 use strict;
@@ -165,7 +165,7 @@ sub startup
     }
     else
     {
-      $self->render(text => $message, status => $status);
+      $self->render(text => $message, status => $status, format => 'txt');
     }
   });
     
@@ -191,7 +191,7 @@ PlugAuth - Pluggable authentication and authorization server.
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
